==> vue-hooks-plus-1.1.4.tgz: package/lib/useRequest/Fetch.js <==
"use strict";
var __defProp = Object.defineProperty;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __publicField = (obj, key, value) => {
  __defNormalProp(obj, typeof key !== "symbol" ? key + "" : key, value);
  return value;
};
class Fetch {
  constructor(serviceRef, options, setUpdataData, initState = {}) {
    __publicField(this, "pluginImpls");
    __publicField(this, "count", 0);
    __publicField(this, "state", {
      loading: false,
      params: void 0,
      data: void 0,
      error: void 0
    });
    this.serviceRef = serviceRef;
    this.options = options;
    this.setUpdataData = setUpdataData;
    this.initState = initState;
    this.state = {
      ...this.state,
      loading: !options.manual,
      ...initState
    };
  }
  setState(s = {}) {
    this.state = {
      ...this.state,
      ...s
    };
    this.setUpdataData(this.state);
  }
  setData(data, key) {
    if (key instanceof Array) {
      key.forEach((k) => {
        this.state[k] = data;
        this.setUpdataData(data, k);
      });
    } else {
      this.state[key] = data;
      this.setUpdataData(data, key);
    }
  }
  runPluginHandler(event, ...rest) {
    var _a, _b, _c;
    const r = (_c = (_b = (_a = this.pluginImpls) == null ? void 0 : _a.map((i) => {
      var _a2;
      return (_a2 = i[event]) == null ? void 0 : _a2.call(i, ...rest);
    })) != null ? _b : []) == null ? void 0 : _c.filter(Boolean);
    return Object.assign({}, ...r);
  }
  async runAsync(...params) {
    var _a, _b, _c, _d, _e, _f, _g, _h, _i, _j;
    this.count += 1;
    const currentCount = this.count;
    const { stopNow = false, returnNow = false, ...state } = this.runPluginHandler(
      "onBefore",
      params
    );
    if (stopNow) {
      return new Promise(() => {
      });
    }
    this.setState({
      loading: true,
      params,
      ...state
    });
    if (returnNow) {
      return Promise.resolve(state.data);
    }
    (_b = (_a = this.options).onBefore) == null ? void 0 : _b.call(_a, params);
    try {
      let { servicePromise } = this.runPluginHandler("onRequest", this.serviceRef.value, params);
      if (!servicePromise) {
        servicePromise = this.serviceRef.value(...params);
      }
      const res = await servicePromise;
      if (currentCount !== this.count) {
        return new Promise(() => {
        });
      }
      this.setState({
        data: res,
        error: void 0,
        loading: false
      });
      (_d = (_c = this.options).onSuccess) == null ? void 0 : _d.call(_c, res, params);
      this.runPluginHandler("onSuccess", res, params);
      (_f = (_e = this.options).onFinally) == null ? void 0 : _f.call(_e, params, res, void 0);
      if (currentCount === this.count) {
        this.runPluginHandler("onFinally", params, res, void 0);
      }
      return res;
    } catch (error) {
      if (currentCount !== this.count) {
        return new Promise(() => {
        });
      }
      this.setState({
        error,
        loading: false
      });
      (_h = (_g = this.options).onError) == null ? void 0 : _h.call(_g, error, params);
      this.runPluginHandler("onError", error, params);
      (_j = (_i = this.options).onFinally) == null ? void 0 : _j.call(_i, params, void 0, error);
      if (currentCount === this.count) {
        this.runPluginHandler("onFinally", params, void 0, error);
      }
      throw error;
    }
  }
  run(...params) {
    this.runAsync(...params).catch((error) => {
      if (!this.options.onError) {
        console.error(error);
      }
    });
  }
  cancel() {
    this.count += 1;
    this.setState({
      loading: false
    });
    this.runPluginHandler("onCancel");
  }
  refresh() {
    this.run(...this.state.params || []);
  }
  refreshAsync() {
    return this.runAsync(...this.state.params || []);
  }
  mutate(data) {
    let targetData;
    if (typeof data === "function") {
      targetData = data == null ? void 0 : data(this.state.data);
    } else {
      targetData = data;
    }
    this.runPluginHandler("onMutate", targetData);
    this.setState({
      data: targetData
    });
  }
}
module.exports = Fetch;

==> vue-hooks-plus-1.5.1.tgz: package/lib/useRequest/Fetch.js <==
"use strict";
var __defProp = Object.defineProperty;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __publicField = (obj, key, value) => {
  __defNormalProp(obj, typeof key !== "symbol" ? key + "" : key, value);
  return value;
};
class Fetch {
  constructor(serviceRef, options, setUpdataData, initState = {}) {
    __publicField(this, "pluginImpls");
    __publicField(this, "count", 0);
    __publicField(this, "state", {
      loading: false,
      params: void 0,
      data: void 0,
      error: void 0
    });
    this.serviceRef = serviceRef;
    this.options = options;
    this.setUpdataData = setUpdataData;
    this.initState = initState;
    this.state = {
      ...this.state,
      loading: !options.manual,
      ...initState
    };
  }
  setState(s = {}) {
    this.state = {
      ...this.state,
      ...s
    };
    this.setUpdataData(this.state);
  }
  setData(data, key) {
    if (key instanceof Array) {
      key.forEach((k) => {
        this.state[k] = data;
        this.setUpdataData(data, k);
      });
    } else {
      this.state[key] = data;
      this.setUpdataData(data, key);
    }
  }
  runPluginHandler(event, ...rest) {
    var _a, _b, _c;
    const r = (_c = (_b = (_a = this.pluginImpls) == null ? void 0 : _a.map((i) => {
      var _a2;
      return (_a2 = i[event]) == null ? void 0 : _a2.call(i, ...rest);
    })) != null ? _b : []) == null ? void 0 : _c.filter(Boolean);
    return Object.assign({}, ...r);
  }
  async runAsync(...params) {
    var _a, _b, _c, _d, _e, _f, _g, _h, _i, _j;
    this.count += 1;
    const currentCount = this.count;
    const { stopNow = false, returnNow = false, ...state } = this.runPluginHandler(
      "onBefore",
      params
    );
    if (stopNow) {
      return new Promise(() => {
      });
    }
    this.setState({
      loading: true,
      params,
      ...state
    });
    if (returnNow) {
      return Promise.resolve(state.data);
    }
    (_b = (_a = this.options).onBefore) == null ? void 0 : _b.call(_a, params);
    try {
      let { servicePromise } = this.runPluginHandler("onRequest", this.serviceRef.value, params);
      if (!servicePromise) {
        servicePromise = this.serviceRef.value(...params);
      }
      const res = await servicePromise;
      if (currentCount !== this.count) {
        return new Promise(() => {
        });
      }
      const formattedResult = this.options.formatResult ? this.options.formatResult(res) : res;
      this.setState({
        data: formattedResult,
        error: void 0,
        loading: false
      });
      (_d = (_c = this.options).onSuccess) == null ? void 0 : _d.call(_c, formattedResult, params);
      this.runPluginHandler("onSuccess", formattedResult, params);
      (_f = (_e = this.options).onFinally) == null ? void 0 : _f.call(_e, params, formattedResult, void 0);
      if (currentCount === this.count) {
        this.runPluginHandler("onFinally", params, formattedResult, void 0);
      }
      return formattedResult;
    } catch (error) {
      if (currentCount !== this.count) {
        return new Promise(() => {
        });
      }
      this.setState({
        error,
        loading: false
      });
      (_h = (_g = this.options).onError) == null ? void 0 : _h.call(_g, error, params);
      this.runPluginHandler("onError", error, params);
      (_j = (_i = this.options).onFinally) == null ? void 0 : _j.call(_i, params, void 0, error);
      if (currentCount === this.count) {
        this.runPluginHandler("onFinally", params, void 0, error);
      }
      throw error;
    }
  }
  run(...params) {
    this.runAsync(...params).catch((error) => {
      if (!this.options.onError) {
        console.error(error);
      }
    });
  }
  cancel() {
    this.count += 1;
    this.setState({
      loading: false
    });
    this.runPluginHandler("onCancel");
  }
  refresh() {
    this.run(...this.state.params || []);
  }
  refreshAsync() {
    return this.runAsync(...this.state.params || []);
  }
  mutate(data) {
    let targetData;
    if (typeof data === "function") {
      targetData = data == null ? void 0 : data(this.state.data);
    } else {
      targetData = data;
    }
    this.runPluginHandler("onMutate", targetData);
    this.setState({
      data: targetData
    });
  }
}
module.exports = Fetch;
